@@ -6,8 +6,6 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 
-from __future__ import absolute_import
-
 import logging
 import os
 
@@ -29,7 +27,7 @@ DEFAULT_SOCKET_MODE = 0o660
 log = logging.getLogger("services")
 
 
-class Service(object):
+class Service:
 
     name = None
 
