@@ -6,17 +6,14 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 
-from __future__ import absolute_import
-
-from six.moves.urllib_parse import urlparse
 import pytest
 
+from urllib.parse import urlparse
+
 from ovirt_imageio._internal import errors
 from ovirt_imageio._internal.backends import image
 from ovirt_imageio._internal.backends import memory
 
-from . marks import requires_python3
-
 
 def test_debugging_interface(tmpurl):
     with memory.open(urlparse("memory:"), "r+") as m:
@@ -259,7 +256,6 @@ def test_user_extents():
     assert list(m.extents("dirty")) == extents["dirty"]
 
 
-@requires_python3
 def test_read_from():
     size = 128
     src = memory.Backend(data=bytearray(b"x" * size))
@@ -272,7 +268,6 @@ def test_read_from():
     assert src.data() == dst.data()
 
 
-@requires_python3
 def test_read_from_some():
     src = memory.Backend(data=bytearray(b"x" * 128))
     dst = memory.ReaderFrom("r+", data=bytearray(b"y" * 128))
@@ -287,7 +282,6 @@ def test_read_from_some():
     assert dst.data() == b"y" * 32 + b"x" * 64 + b"y" * 32
 
 
-@requires_python3
 def test_write_to():
     size = 128
     src = memory.WriterTo(data=bytearray(b"x" * size))
@@ -300,7 +294,6 @@ def test_write_to():
     assert src.data() == dst.data()
 
 
-@requires_python3
 def test_write_to_some():
     size = 128
     src = memory.WriterTo(data=bytearray(b"x" * size))
