@@ -6,14 +6,12 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 
-from __future__ import absolute_import
-
 import logging
 import time
 
 from contextlib import contextmanager
 
-from six.moves.urllib.parse import urlparse
+from urllib.parse import urlparse
 
 from ovirt_imageio._internal import nbd
 from ovirt_imageio._internal import nbdutil
@@ -55,7 +53,7 @@ def run(qmp, sock, scratch_disk, checkpoint=None, incremental=None):
         b.stop()
 
 
-class Backup(object):
+class Backup:
 
     def __init__(self, qmp, sock, scratch_disk, checkpoint=None,
                  incremental=None):
