@@ -6,8 +6,6 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 
-from __future__ import absolute_import
-
 import logging
 import os
 import re
@@ -98,7 +96,7 @@ def run(image, fmt, qmp_sock=None, start_cpu=True, shutdown_timeout=1):
         log.debug("qemu terminated with exit code %s", p.returncode)
 
 
-class Guest(object):
+class Guest:
 
     def __init__(self, p):
         self._stdin = p.stdin
